@@ -25,15 +25,6 @@ type ConfigProvider interface {
 	loggingConfig
 }
 
-// TODO: Remove this function once Helmfile v0.x
-type DeprecatedChartsConfigProvider interface {
-	Values() []string
-
-	concurrencyConfig
-	loggingConfig
-	IncludeTransitiveNeeds() bool
-}
-
 type DepsConfigProvider interface {
 	Args() string
 	SkipRepos() bool
@@ -82,9 +73,6 @@ type ApplyConfigProvider interface {
 	Context() int
 	DiffOutput() string
 
-	// TODO: Remove this function once Helmfile v0.x
-	RetainValuesFiles() bool
-
 	Validate() bool
 	SkipCleanup() bool
 	SkipDiffOnInstall() bool
@@ -92,6 +80,8 @@ type ApplyConfigProvider interface {
 	DiffArgs() string
 	SyncArgs() string
 
+	SyncReleaseLabels() bool
+
 	DAGConfig
 
 	concurrencyConfig
@@ -103,6 +93,7 @@ type ApplyConfigProvider interface {
 type SyncConfigProvider interface {
 	Args() string
 	PostRenderer() string
+	SkipSchemaValidation() bool
 	PostRendererArgs() []string
 	HideNotes() bool
 	TakeOwnership() bool
@@ -123,6 +114,9 @@ type SyncConfigProvider interface {
 	SkipNeeds() bool
 	IncludeNeeds() bool
 	IncludeTransitiveNeeds() bool
+
+	SyncReleaseLabels() bool
+
 	DAGConfig
 
 	concurrencyConfig
@@ -163,28 +157,12 @@ type DiffConfigProvider interface {
 	NoColor() bool
 	Context() int
 	DiffOutput() string
+	TakeOwnership() bool
 
 	concurrencyConfig
 	valuesControlMode
 }
 
-// TODO: Remove this function once Helmfile v0.x
-type DeleteConfigProvider interface {
-	Args() string
-	Cascade() string
-
-	Purge() bool
-	SkipDeps() bool
-	SkipRefresh() bool
-	SkipCharts() bool
-	DeleteWait() bool
-	DeleteTimeout() int
-
-	interactive
-	loggingConfig
-	concurrencyConfig
-}
-
 type DestroyConfigProvider interface {
 	Args() string
 	Cascade() string
@@ -239,6 +217,7 @@ type TemplateConfigProvider interface {
 	Args() string
 	PostRenderer() string
 	PostRendererArgs() []string
+	SkipSchemaValidation() bool
 
 	Values() []string
 	Set() []string
