@@ -7,6 +7,8 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/fatih/color"
+
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/state"
 )
@@ -135,17 +137,6 @@ func (r *Run) Repos(c ReposConfigProvider) error {
 	return r.ctx.SyncReposOnce(r.state, r.helm)
 }
 
-// TODO: Remove this function once Helmfile v0.x
-func (r *Run) DeprecatedSyncCharts(c DeprecatedChartsConfigProvider) []error {
-	st := r.state
-	helm := r.helm
-
-	affectedReleases := state.AffectedReleases{}
-	errs := st.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency())
-	affectedReleases.DisplayAffectedReleases(c.Logger())
-	return errs
-}
-
 func (r *Run) diff(triggerCleanupEvent bool, detailedExitCode bool, c DiffConfigProvider, diffOpts *state.DiffOpts) (*string, map[string]state.ReleaseSpec, map[string]state.ReleaseSpec, []error) {
 	st := r.state
 	helm := r.helm
@@ -216,7 +207,11 @@ func (r *Run) diff(triggerCleanupEvent bool, detailedExitCode bool, c DiffConfig
 		names = append(names, fmt.Sprintf("  %s (%s) UPDATED", r.Name, r.Chart))
 	}
 	for _, r := range releasesToBeDeleted {
-		names = append(names, fmt.Sprintf("  %s (%s) DELETED", r.Name, r.Chart))
+		releaseToBeDeleted := fmt.Sprintf("  %s (%s) DELETED", r.Name, r.Chart)
+		if c.Color() {
+			releaseToBeDeleted = color.RedString(releaseToBeDeleted)
+		}
+		names = append(names, releaseToBeDeleted)
 	}
 	// Make the output deterministic for testing purpose
 	sort.Strings(names)
