@@ -58,11 +58,11 @@ func (f fakeInit) Force() bool {
 }
 
 func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
-	t.Run("with gopkg.in/yaml.v3", func(t *testing.T) {
+	t.Run("with go.yaml.in/yaml/v3", func(t *testing.T) {
 		testHelmfileTemplateWithBuildCommand(t, true)
 	})
 
-	t.Run("with gopkg.in/yaml.v2", func(t *testing.T) {
+	t.Run("with go.yaml.in/yaml/v2", func(t *testing.T) {
 		testHelmfileTemplateWithBuildCommand(t, false)
 	})
 }
